@@ -66,6 +66,32 @@ def localgec_todsk(essay_or_snts:str="She has ready. It are ok.", device:int=-1,
 	import pipe #pip install torch transformers| cp model
 	return todsk(essay_or_snts, asdsk=asdsk, dskhost=dskhost, debug=debug, gec_func = lambda snts: pipe.gecsnts(snts, device=device))
 
+def essay_to_dsk(arr:dict={'essay_or_snts':"She has ready. It are ok.", # arr from mq 
+	'formula':{   # five-range-value, cate, coef, cate-coef
+"ast":[9.9, 11.99, 15.3, 18.51, 25.32,				2,0.0882, 0.3241],
+"awl":[3.5, 4.1, 4.56, 5.1, 6.0,					3,0.0882, 0.5],
+"b3":[0, 0.03, 0.08, 0.12, 0.15 ,					1, 0.0956, 0.2096],
+"cl_sum":[1, 6.68, 12, 16, 26,						2,0.0441, 0.1621],
+"grammar_correct_ri":[0.6, 0.85, 0.92, 0.97,1.0,	2,0.0368, 0.1352],
+"internal_sim":[0.0, 0.08, 0.2, 0.3, 0.4,			4, 0.0735, 0.7688],
+"kp_correct_ri":[0.7, 0.9, 0.95, 0.97, 1,			1, 0.0368, 0.0807],
+"mwe_pv":[0.01,8.03, 12, 20.21, 25,					4, 0.0221, 0.2312],
+"pred_diff_max3":[3.84, 5.11, 6.51, 7.9, 10.09 ,	1, 0.0368, 0.0807],
+"prmods_ratio":[0.06, 0.21, 0.3, 0.4, 0.5,			2, 0.0294, 0.108],
+"prmods_tc":[1.1, 2.76, 4.75, 6.76, 10.0,			2, 0.0368, 0.1352],
+"simple_sent_ri":[0.4, 0.65, 0.9, 0.95, 1,			2, 0.0368, 0.1352],
+"snt_correct_ratio":[0.01, 0.2, 0.45, 0.75, 1,		1, 0.0368, 0.0807],
+"spell_correct_ratio":[0.8, 0.9, 0.97, 0.99, 1,		1, 0.1471, 0.3226],
+"ttr1":[3.43, 4.28, 5.2, 6, 6.8,					3, 0.0882, 0.5],
+"word_diff_avg":[4.47, 4.73, 5.25,5.8, 6.6,			1, 0.0441, 0.0967],
+"word_gt7":[0.11, 0.19, 0.3, 0.42, 0.49,			1, 0.0588, 0.1289]}}): 
+	''' '''
+	from dsk import score 
+	res = todsk(arr.get('essay_or_snts',''), arr.get('asdsk',True), arr.get('dskhost','172.17.0.1:7095') ) 
+	if 'formula' in arr and isinstance(res, dict) and 'info' in res: 
+		res['info'].update(  score.dims_score(res['doc'], arr['formula'])) # reset the score 
+	return res 
+
 def init_dskmkf_table(cursor):
 	cursor.execute('''CREATE TABLE if not exists `dsk` (
   `eidv` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT '{eid}-{ver}',
