@@ -27,6 +27,15 @@ def gecsnts(snts:list=["She has ready.","It are ok."],  max_length:int=128,  do_
 		offset = offset + batch_size
 	return dic
 
+def getgecs(snts:list=["She has ready.","It are ok."], gechost:str='gpu120.wrask.com:8180', rport:int=6379, timeout:int=5
+	,  max_length:int=128,  do_sample:bool=False, batch_size:int=64, unchanged_ratio:float=0.45, len_ratio:float=0.5, model:str="/grammar_error_correcter_v1", device:int=-1): 
+	''' 2022.6.4 '''
+	import requests 
+	sntdic	=  requests.post(f"http://{gechost}/redis/getgecs", params={"port":rport, "timeout":timeout}, json=snts).json () 
+	if not sntdic :  # failed 
+		sntdic = gecsnts(snts, max_length=max_length,do_sample=do_sample, batch_size =batch_size, unchanged_ratio=unchanged_ratio, len_ratio = len_ratio, model =model, device=device)
+	return sntdic 
+
 ## wrapper web api for uvicorn
 
 def redis_getgecs(snts:list=["She has ready.","It are ok."], xname:str='xsnts', host:str="172.17.0.1", port:int=6379, db:int=0, timeout:int=5): # put into the ufw white ip list 
