@@ -30,6 +30,13 @@ def uvirun(port):
 
 	uvicorn.run(app, host='0.0.0.0', port=port)
 
+def testredis(snts:list=["She has ready.","It are ok."], xname:str='xsnts', host:str="172.17.0.1", port:int=6379, db:int=0, timeout:int=5):
+	''' test redis gec '''
+	import time
+	start = time.time()
+	res = pipe.redis_getgecs(snts, xname, host, port, db, timeout)
+	print (res, "\ttiming:", time.time() - start) 
+
 if __name__ == '__main__':  #{'She has ready.': 'She is ready.', 'It are ok.': 'It is ok.'}
 	import fire
-	fire.Fire({"uvirun":uvirun, "testredis": lambda : print(pipe.redis_getgecs()), 'testlocal': lambda: print(pipe.gecsnts())})
\ No newline at end of file
+	fire.Fire({"uvirun":uvirun, "testredis": testredis, 'remoteredis': print(pipe.redis_getgecs(host='gpu120.wrask.com')),  'testlocal': lambda: print(pipe.gecsnts())})
\ No newline at end of file
